@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,7 +24,7 @@ EditorUtil::EditorUtil()
 {
 }
 
-void EditorUtil::upperCase(QTextCursor &cursor)
+void EditorUtil::upperCase(QTextCursor &cursor) const
 {
     if (cursor.hasSelection()) {
         const QString newText = cursor.selectedText().toUpper();
@@ -32,7 +32,7 @@ void EditorUtil::upperCase(QTextCursor &cursor)
     }
 }
 
-void EditorUtil::lowerCase(QTextCursor &cursor)
+void EditorUtil::lowerCase(QTextCursor &cursor) const
 {
     if (cursor.hasSelection()) {
         const QString newText = cursor.selectedText().toLower();
@@ -40,7 +40,7 @@ void EditorUtil::lowerCase(QTextCursor &cursor)
     }
 }
 
-void EditorUtil::sentenceCase(QTextCursor &cursor)
+void EditorUtil::sentenceCase(QTextCursor &cursor) const
 {
     if (cursor.hasSelection()) {
         QString newText = cursor.selectedText();
@@ -61,10 +61,10 @@ void EditorUtil::sentenceCase(QTextCursor &cursor)
     }
 }
 
-void EditorUtil::reverseCase(QTextCursor &cursor)
+void EditorUtil::reverseCase(QTextCursor &cursor) const
 {
     if (cursor.hasSelection()) {
-        QString newText = cursor.selectedText();
+        const QString newText = cursor.selectedText();
         QString reverseCaseText;
         const int nbChar(newText.count());
         for (int i = 0; i < nbChar; ++i) {
